@@ -1,16 +1,16 @@
 /* glpk.h */
 
 /***********************************************************************
-*  This code is part of GNU Linear Programming Kit (GLPK).
+*  This code is part of GLPK (GNU Linear Programming Kit).
 *
 *  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
 *  Department for Applied Informatics, Moscow Aviation Institute,
 *  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 *
-*  GLPK is free software; you can redistribute it and/or modify it
+*  GLPK is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by
-*  the Free Software Foundation; either version 2, or (at your option)
-*  any later version.
+*  the Free Software Foundation, either version 3 of the License, or
+*  (at your option) any later version.
 *
 *  GLPK is distributed in the hope that it will be useful, but WITHOUT
 *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
@@ -18,9 +18,7 @@
 *  License for more details.
 *
 *  You should have received a copy of the GNU General Public License
-*  along with GLPK; see the file COPYING. If not, write to the Free
-*  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-*  02110-1301, USA.
+*  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 #ifndef _GLPK_H
@@ -32,9 +30,10 @@ extern "C" {
 
 /* library version numbers: */
 #define GLP_MAJOR_VERSION  4
-#define GLP_MINOR_VERSION  17
+#define GLP_MINOR_VERSION  25
 
-#ifndef _GLPAPI_PRIVATE
+#ifndef _GLP_PROB
+#define _GLP_PROB
 typedef struct { double _prob; } glp_prob;
 /* LP/MIP problem object */
 #endif
@@ -70,8 +69,139 @@ typedef struct { double _prob; } glp_prob;
 #define GLP_OPT         5  /* solution is optimal */
 #define GLP_UNBND       6  /* solution is unbounded */
 
+#ifndef _GLP_ULONG
+#define _GLP_ULONG
 typedef struct { unsigned int lo, hi; } glp_ulong;
 /* 64-bit unsigned integer data type */
+#endif
+
+#ifndef _GLP_BFCP
+#define _GLP_BFCP
+typedef struct glp_bfcp glp_bfcp;
+#endif
+
+struct glp_bfcp
+{     /* basis factorization control parameters */
+      int msg_lev;         /* (reserved) */
+      int type;            /* factorization type: */
+#define GLP_BF_FT       1  /* LUF + Forrest-Tomlin */
+#define GLP_BF_BG       2  /* LUF + Schur compl. + Bartels-Golub */
+#define GLP_BF_GR       3  /* LUF + Schur compl. + Givens rotation */
+      int lu_size;         /* luf.sv_size */
+      double piv_tol;      /* luf.piv_tol */
+      int piv_lim;         /* luf.piv_lim */
+      int suhl;            /* luf.suhl */
+      double eps_tol;      /* luf.eps_tol */
+      double max_gro;      /* luf.max_gro */
+      int nfs_max;         /* fhv.hh_max */
+      double upd_tol;      /* fhv.upd_tol */
+      int nrs_max;         /* lpf.n_max */
+      int rs_size;         /* lpf.v_size */
+      double foo_bar[38];  /* (reserved) */
+};
+
+typedef struct
+{     /* simplex method control parameters */
+      int msg_lev;         /* message level: */
+#define GLP_MSG_OFF     0  /* no output */
+#define GLP_MSG_ERR     1  /* warning and error messages only */
+#define GLP_MSG_ON      2  /* normal output */
+#define GLP_MSG_ALL     3  /* full output */
+      int meth;            /* simplex method option: */
+#define GLP_PRIMAL      1  /* use primal simplex */
+#define GLP_DUALP       2  /* use dual simplex, if possible */
+      int pricing;         /* pricing technique: */
+#define GLP_PT_STD   0x11  /* standard (textbook) */
+#define GLP_PT_PSE   0x22  /* projected steepest edge */
+      int r_test;          /* ratio test technique: */
+#define GLP_RT_STD   0x11  /* standard (textbook) */
+#define GLP_RT_HAR   0x22  /* Harris' ratio test */
+      double tol_bnd;      /* spx.tol_bnd */
+      double tol_dj;       /* spx.tol_dj */
+      double tol_piv;      /* spx.tol_piv */
+      double obj_ll;       /* spx.obj_ll */
+      double obj_ul;       /* spx.obj_ul */
+      int it_lim;          /* spx.it_lim */
+      int tm_lim;          /* spx.tm_lim (milliseconds) */
+      int out_frq;         /* spx.out_frq */
+      int out_dly;         /* spx.out_dly (milliseconds) */
+      int presolve;        /* enable/disable using LP presolver */
+      double foo_bar[36];  /* (reserved) */
+} glp_smcp;
+
+#ifndef _GLP_TREE
+#define _GLP_TREE
+typedef struct { double _tree; } glp_tree;
+/* branch-and-bound tree */
+#endif
+
+typedef struct
+{     /* integer optimizer control parameters */
+      int msg_lev;         /* message level: */
+#define GLP_MSG_OFF     0  /* no output */
+#define GLP_MSG_ERR     1  /* warning and error messages only */
+#define GLP_MSG_ON      2  /* normal output */
+#define GLP_MSG_ALL     3  /* full output */
+#define GLP_MSG_DBG     4  /* debug output */
+      int br_tech;         /* branching technique: */
+#define GLP_BR_FFV      1  /* first fractional variable */
+#define GLP_BR_LFV      2  /* last fractional variable */
+#define GLP_BR_MFV      3  /* most fractional variable */
+#define GLP_BR_DTH      4  /* heuristic by Driebeck and Tomlin */
+      int bt_tech;         /* backtracking technique: */
+#define GLP_BT_DFS      1  /* depth first search */
+#define GLP_BT_BFS      2  /* breadth first search */
+#define GLP_BT_BLB      3  /* best local bound */
+#define GLP_BT_BPH      4  /* best projection heuristic */
+      double tol_int;      /* mip.tol_int */
+      double tol_obj;      /* mip.tol_obj */
+      int tm_lim;          /* mip.tm_lim (milliseconds) */
+      int out_frq;         /* mip.out_frq (milliseconds) */
+      int out_dly;         /* mip.out_dly (milliseconds) */
+      void (*cb_func)(glp_tree *tree, void *info);
+                           /* mip.cb_func */
+      void *cb_info;       /* mip.cb_info */
+      int cb_size;         /* mip.cb_size */
+      int pp_tech;         /* preprocessing technique: */
+#define GLP_PP_NONE     0  /* disable preprocessing */
+#define GLP_PP_ROOT     1  /* preprocessing only on root level */
+#define GLP_PP_ALL      2  /* preprocessing on all levels */
+      double mip_gap;      /* relative MIP gap tolerance */
+      int mir_cuts;        /* MIR cuts (GLP_ON/GLP_OFF) */
+      int gmi_cuts;        /* Gomory's cuts (GLP_ON/GLP_OFF) */
+      double foo_bar[34];  /* (reserved) */
+#if 1 /* not yet available */
+      char *fn_sol;        /* file name to write solution found */
+#endif
+} glp_iocp;
+
+/* enable/disable flag: */
+#define GLP_ON          1  /* enable something */
+#define GLP_OFF         0  /* disable something */
+
+/* reason codes: */
+#define GLP_IROWGEN  0x01  /* request for row generation */
+#define GLP_IBINGO   0x02  /* better integer solution found */
+#define GLP_IHEUR    0x03  /* request for heuristic solution */
+#define GLP_ICUTGEN  0x04  /* request for cut generation */
+#define GLP_IBRANCH  0x05  /* request for branching */
+#define GLP_ISELECT  0x06  /* request for subproblem selection */
+#define GLP_IPREPRO  0x07  /* request for preprocessing */
+
+/* return codes: */
+#define GLP_EBADB    0x01  /* invalid basis */
+#define GLP_ESING    0x02  /* singular matrix */
+#define GLP_ECOND    0x03  /* ill-conditioned matrix */
+#define GLP_EBOUND   0x04  /* invalid bounds */
+#define GLP_EFAIL    0x05  /* solver failed */
+#define GLP_EOBJLL   0x06  /* objective lower limit reached */
+#define GLP_EOBJUL   0x07  /* objective upper limit reached */
+#define GLP_EITLIM   0x08  /* iteration limit exceeded */
+#define GLP_ETMLIM   0x09  /* time limit exceeded */
+#define GLP_ENOPFS   0x0A  /* no primal feasible solution */
+#define GLP_ENODFS   0x0B  /* no dual feasible solution */
+#define GLP_EROOT    0x0C  /* root LP optimum not provided */
+#define GLP_ESTOP    0x0D  /* serach terminated by application */
 
 glp_prob *glp_create_prob(void);
 /* create problem object */
@@ -192,12 +322,39 @@ int glp_find_col(glp_prob *lp, const char *name);
 void glp_delete_index(glp_prob *lp);
 /* delete the name index */
 
+void glp_set_rii(glp_prob *lp, int i, double rii);
+/* set (change) row scale factor */
+
+void glp_set_sjj(glp_prob *lp, int j, double sjj);
+/* set (change) column scale factor */
+
+double glp_get_rii(glp_prob *lp, int i);
+/* retrieve row scale factor */
+
+double glp_get_sjj(glp_prob *lp, int j);
+/* retrieve column scale factor */
+
+void glp_unscale_prob(glp_prob *lp);
+/* unscale problem data */
+
 void glp_set_row_stat(glp_prob *lp, int i, int stat);
 /* set (change) row status */
 
 void glp_set_col_stat(glp_prob *lp, int j, int stat);
 /* set (change) column status */
 
+int glp_simplex(glp_prob *lp, const glp_smcp *parm);
+/* solve LP problem with the simplex method */
+
+void glp_init_smcp(glp_smcp *parm);
+/* initialize simplex method control parameters */
+
+int glp_get_row_stat(glp_prob *lp, int i);
+/* retrieve row status */
+
+int glp_get_col_stat(glp_prob *lp, int j);
+/* retrieve column status */
+
 int glp_get_status(glp_prob *lp);
 /* retrieve generic status of basic solution */
 
@@ -210,24 +367,21 @@ int glp_get_dual_stat(glp_prob *lp);
 double glp_get_obj_val(glp_prob *lp);
 /* retrieve objective value (basic solution) */
 
-int glp_get_row_stat(glp_prob *lp, int i);
-/* retrieve row status (basic solution) */
-
 double glp_get_row_prim(glp_prob *lp, int i);
 /* retrieve row primal value (basic solution) */
 
 double glp_get_row_dual(glp_prob *lp, int i);
 /* retrieve row dual value (basic solution) */
 
-int glp_get_col_stat(glp_prob *lp, int j);
-/* retrieve column status (basic solution) */
-
 double glp_get_col_prim(glp_prob *lp, int j);
 /* retrieve column primal value (basic solution) */
 
 double glp_get_col_dual(glp_prob *lp, int j);
 /* retrieve column dual value (basic solution) */
 
+int glp_ipt_status(glp_prob *lp);
+/* retrieve status of interior-point solution */
+
 double glp_ipt_obj_val(glp_prob *lp);
 /* retrieve objective value (interior point) */
 
@@ -243,37 +397,178 @@ double glp_ipt_col_prim(glp_prob *lp, int j);
 double glp_ipt_col_dual(glp_prob *lp, int j);
 /* retrieve column dual value (interior point) */
 
-void glp_set_col_kind(glp_prob *lp, int j, int kind);
+void glp_set_col_kind(glp_prob *mip, int j, int kind);
 /* set (change) column kind */
 
-int glp_get_col_kind(glp_prob *lp, int j);
+int glp_get_col_kind(glp_prob *mip, int j);
 /* retrieve column kind */
 
-int glp_get_num_int(glp_prob *lp);
+int glp_get_num_int(glp_prob *mip);
 /* retrieve number of integer columns */
 
-int glp_get_num_bin(glp_prob *lp);
+int glp_get_num_bin(glp_prob *mip);
 /* retrieve number of binary columns */
 
-double glp_mip_obj_val(glp_prob *lp);
+int glp_intopt(glp_prob *mip, const glp_iocp *parm);
+/* solve MIP problem with the branch-and-bound method */
+
+void glp_init_iocp(glp_iocp *parm);
+/* initialize integer optimizer control parameters */
+
+int glp_mip_status(glp_prob *mip);
+/* retrieve status of MIP solution */
+
+double glp_mip_obj_val(glp_prob *mip);
 /* retrieve objective value (MIP solution) */
 
-double glp_mip_row_val(glp_prob *lp, int i);
+double glp_mip_row_val(glp_prob *mip, int i);
 /* retrieve row value (MIP solution) */
 
-double glp_mip_col_val(glp_prob *lp, int j);
+double glp_mip_col_val(glp_prob *mip, int j);
 /* retrieve column value (MIP solution) */
 
+int glp_read_sol(glp_prob *lp, const char *fname);
+/* read basic solution from text file */
+
+int glp_write_sol(glp_prob *lp, const char *fname);
+/* write basic solution to text file */
+
+int glp_read_ipt(glp_prob *lp, const char *fname);
+/* read interior-point solution from text file */
+
+int glp_write_ipt(glp_prob *lp, const char *fname);
+/* write interior-point solution to text file */
+
+int glp_read_mip(glp_prob *mip, const char *fname);
+/* read MIP solution from text file */
+
+int glp_write_mip(glp_prob *mip, const char *fname);
+/* write MIP solution to text file */
+
+int glp_bf_exists(glp_prob *lp);
+/* check if the basis factorization exists */
+
+int glp_factorize(glp_prob *lp);
+/* compute the basis factorization */
+
+int glp_bf_updated(glp_prob *lp);
+/* check if the basis factorization has been updated */
+
+void glp_get_bfcp(glp_prob *lp, glp_bfcp *parm);
+/* retrieve basis factorization control parameters */
+
+void glp_set_bfcp(glp_prob *lp, const glp_bfcp *parm);
+/* change basis factorization control parameters */
+
+int glp_get_bhead(glp_prob *lp, int k);
+/* retrieve the basis header information */
+
+int glp_get_row_bind(glp_prob *lp, int i);
+/* retrieve row index in the basis header */
+
+int glp_get_col_bind(glp_prob *lp, int j);
+/* retrieve column index in the basis header */
+
+void glp_ftran(glp_prob *lp, double x[]);
+/* perform forward transformation (solve system B*x = b) */
+
+void glp_btran(glp_prob *lp, double x[]);
+/* perform backward transformation (solve system B'*x = b) */
+
+int glp_eval_tab_row(glp_prob *lp, int k, int ind[], double val[]);
+/* compute row of the simplex tableau */
+
+int glp_eval_tab_col(glp_prob *lp, int k, int ind[], double val[]);
+/* compute column of the simplex tableau */
+
+int glp_ios_reason(glp_tree *tree);
+/* determine reason for calling the callback routine */
+
+glp_prob *glp_ios_get_prob(glp_tree *tree);
+/* access the problem object */
+
+void glp_ios_tree_size(glp_tree *tree, int *a_cnt, int *n_cnt,
+      int *t_cnt);
+/* determine size of the branch-and-bound tree */
+
+int glp_ios_curr_node(glp_tree *tree);
+/* determine current active subproblem */
+
+int glp_ios_next_node(glp_tree *tree, int p);
+/* determine next active subproblem */
+
+int glp_ios_prev_node(glp_tree *tree, int p);
+/* determine previous active subproblem */
+
+int glp_ios_up_node(glp_tree *tree, int p);
+/* determine parent subproblem */
+
+int glp_ios_node_level(glp_tree *tree, int p);
+/* determine subproblem level */
+
+double glp_ios_node_bound(glp_tree *tree, int p);
+/* determine subproblem local bound */
+
+int glp_ios_best_node(glp_tree *tree);
+/* find active subproblem with best local bound */
+
+double glp_ios_mip_gap(glp_tree *tree);
+/* compute relative MIP gap */
+
+void *glp_ios_node_data(glp_tree *tree, int p);
+/* access subproblem application-specific data */
+
+int glp_ios_can_branch(glp_tree *tree, int j);
+/* check if can branch upon specified variable */
+
+void glp_ios_branch_upon(glp_tree *tree, int j, int sel);
+/* choose variable to branch upon */
+
+void glp_ios_select_node(glp_tree *tree, int p);
+/* select subproblem to continue the search */
+
+int glp_ios_heur_sol(glp_tree *tree, const double x[]);
+/* provide solution found by heuristic */
+
+void glp_ios_terminate(glp_tree *tree);
+/* terminate the solution process */
+
 const char *glp_version(void);
 /* determine library version */
 
+void glp_term_out(int flag);
+/* enable/disable terminal output */
+
 void glp_term_hook(int (*func)(void *info, const char *s), void *info);
 /* install hook to intercept terminal output */
 
+void *glp_malloc(int size);
+/* allocate memory block */
+
+void *glp_calloc(int n, int size);
+/* allocate memory block */
+
+void glp_free(void *ptr);
+/* free memory block */
+
 void glp_mem_usage(int *count, int *cpeak, glp_ulong *total,
       glp_ulong *tpeak);
 /* get memory usage information */
 
+void glp_mem_limit(int limit);
+/* set memory usage limit */
+
+#ifdef EOF
+FILE *glp_fopen(const char *fname, const char *mode);
+/* open file */
+
+void glp_fclose(FILE *fp);
+/* close file */
+#endif
+
+void glp_free_env(void);
+/* free GLPK library environment */
+
 /**********************************************************************/
 
 #define LPX glp_prob
@@ -382,11 +677,13 @@ void glp_mem_usage(int *count, int *cpeak, glp_ulong *total,
 #define LPX_K_PRESOL    327   /* lp->presol */
 #define LPX_K_BINARIZE  328   /* lp->binarize */
 #define LPX_K_USECUTS   329   /* lp->use_cuts */
-#define LPX_K_BFTYPE    330   /* lp->bf_type */
+#define LPX_K_BFTYPE    330   /* lp->bfcp->type */
+#define LPX_K_MIPGAP    331   /* lp->mip_gap */
 
 #define LPX_C_COVER     0x01  /* mixed cover cuts */
 #define LPX_C_CLIQUE    0x02  /* clique cuts */
 #define LPX_C_GOMORY    0x04  /* Gomory's mixed integer cuts */
+#define LPX_C_MIR       0x08  /* mixed integer rounding cuts */
 #define LPX_C_ALL       0xFF  /* all cuts */
 
 typedef struct
@@ -921,6 +1218,18 @@ int lpx_print_ips(LPX *lp, const char *fname);
 int lpx_print_mip(LPX *lp, const char *fname);
 /* write MIP problem solution in printable format */
 
+#define lpx_is_b_avail _glp_lpx_is_b_avail
+int lpx_is_b_avail(LPX *lp);
+/* check if LP basis is available */
+
+#define lpx_write_pb _glp_lpx_write_pb
+int lpx_write_pb(LPX *lp, const char *fname, int normalized);
+/* write problem data in (normalized) OPB format */
+
+#define lpx_main _glp_lpx_main
+int lpx_main(int argc, const char *argv[]);
+/* stand-alone LP/MIP solver */
+
 #ifdef __cplusplus
 }
 #endif
