@@ -18,7 +18,7 @@
 *  License for more details.
 *
 *  You should have received a copy of the GNU General Public License
-*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+*  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 #ifndef _GLPRNG_H
@@ -44,16 +44,24 @@ void rng_init_rand(RNG *rand, int seed);
 
 #define rng_next_rand _glp_rng_next_rand
 int rng_next_rand(RNG *rand);
-/* obtain pseudo-random integer in [0, 2^31-1] */
+/* obtain pseudo-random integer in the range [0, 2^31-1] */
 
 #define rng_unif_rand _glp_rng_unif_rand
 int rng_unif_rand(RNG *rand, int m);
-/* obtain pseudo-random integer in [0, m-1] */
+/* obtain pseudo-random integer in the range [0, m-1] */
 
 #define rng_delete_rand _glp_rng_delete_rand
 void rng_delete_rand(RNG *rand);
 /* delete pseudo-random number generator */
 
+#define rng_unif_01 _glp_rng_unif_01
+double rng_unif_01(RNG *rand);
+/* obtain pseudo-random number in the range [0, 1] */
+
+#define rng_uniform _glp_rng_uniform
+double rng_uniform(RNG *rand, double a, double b);
+/* obtain pseudo-random number in the range [a, b] */
+
 #endif
 
 /* eof */
