@@ -18,7 +18,7 @@
 *  License for more details.
 *
 *  You should have received a copy of the GNU General Public License
-*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+*  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 #include "glpapi.h"
@@ -52,7 +52,7 @@
 *  RETURNS
 *
 *  0  The LP problem instance has been successfully solved. This code
-*     does not necessarily means that the solver has found optimal
+*     does not necessarily mean that the solver has found optimal
 *     solution. It only means that the solution process was successful.
 *
 *  GLP_EBADB
@@ -158,10 +158,10 @@ up:            col->stat = GLP_NU;
          if (lp->dbs_stat == GLP_NOFEAS && lp->some == 0)
             lp->some = j;
       }
-      if (parm->msg_lev >= 2 && parm->out_dly == 0)
+      if (parm->msg_lev >= GLP_MSG_ON && parm->out_dly == 0)
       {  xprintf("~%6d:   objval = %17.9e   infeas = %17.9e\n",
             lp->it_cnt, lp->obj_val);
-         if (parm->msg_lev >= 3)
+         if (parm->msg_lev >= GLP_MSG_ALL)
          {  if (lp->dbs_stat == GLP_FEAS)
                xprintf("OPTIMAL SOLUTION FOUND\n");
             else
@@ -204,10 +204,10 @@ static void trivial2(glp_prob *lp, const glp_smcp *parm)
                xassert(lp != lp);
          }
       }
-      if (parm->msg_lev >= 2 && parm->out_dly == 0)
+      if (parm->msg_lev >= GLP_MSG_ON && parm->out_dly == 0)
       {  xprintf("~%6d:   objval = %17.9e   infeas = %17.9e\n",
             lp->it_cnt, lp->obj_val);
-         if (parm->msg_lev >= 3)
+         if (parm->msg_lev >= GLP_MSG_ALL)
          {  if (lp->pbs_stat == GLP_FEAS)
                xprintf("OPTIMAL SOLUTION FOUND\n");
             else
@@ -234,8 +234,17 @@ static int simplex1(glp_prob *lp, const glp_smcp *parm)
          {  case 0:
                break;
             case GLP_EBADB:
+               if (parm->msg_lev >= GLP_MSG_ERR)
+                  xprintf("glp_simplex: initial basis is invalid\n");
+               goto done;
             case GLP_ESING:
+               if (parm->msg_lev >= GLP_MSG_ERR)
+                  xprintf("glp_simplex: initial basis is singular\n");
+               goto done;
             case GLP_ECOND:
+               if (parm->msg_lev >= GLP_MSG_ERR)
+                  xprintf("glp_simplex: initial basis is ill-conditione"
+                     "d\n");
                goto done;
             default:
                xassert(ret != ret);
@@ -413,9 +422,9 @@ static int simplex1(glp_prob *lp, const glp_smcp *parm)
       spx->obj_ul  = parm->obj_ul;
       spx->it_lim  = parm->it_lim;
       spx->it_cnt  = lp->it_cnt;
-      spx->tm_lim  = 1000.0 * parm->tm_lim;
+      spx->tm_lim  = 0.001 * (double)parm->tm_lim;
       spx->out_frq = parm->out_frq;
-      spx->out_dly = 1000.0 * parm->out_dly;
+      spx->out_dly = 0.001 * (double)parm->out_dly;
       spx->meth = 0;
       ret = spx_simplex(spx);
       lp->it_cnt = spx->it_cnt;
@@ -514,7 +523,7 @@ static int simplex2(glp_prob *orig, const glp_smcp *parm)
       orig_m = glp_get_num_rows(orig);
       orig_n = glp_get_num_cols(orig);
       orig_nnz = glp_get_num_nz(orig);
-      if (parm->msg_lev >= 3)
+      if (parm->msg_lev >= GLP_MSG_ALL)
       {  xprintf("glp_simplex: original LP has %d row%s, %d column%s, %"
             "d non-zero%s\n",
             orig_m, orig_m == 1 ? "" : "s",
@@ -535,13 +544,13 @@ static int simplex2(glp_prob *orig, const glp_smcp *parm)
             break;
          case 1:
             /* the original problem is primal infeasible */
-            if (parm->msg_lev >= 3)
+            if (parm->msg_lev >= GLP_MSG_ALL)
                xprintf("PROBLEM HAS NO PRIMAL FEASIBLE SOLUTION\n");
             lpp_delete_wksp(lpp);
             return GLP_ENOPFS;
          case 2:
             /* the original problem is dual infeasible */
-            if (parm->msg_lev >= 3)
+            if (parm->msg_lev >= GLP_MSG_ALL)
                xprintf("PROBLEM HAS NO DUAL FEASIBLE SOLUTION\n");
             lpp_delete_wksp(lpp);
             return GLP_ENODFS;
@@ -553,7 +562,7 @@ static int simplex2(glp_prob *orig, const glp_smcp *parm)
       if (lpp->row_ptr == NULL || lpp->col_ptr == NULL)
       {  xassert(lpp->row_ptr == NULL);
          xassert(lpp->col_ptr == NULL);
-         if (parm->msg_lev >= 3)
+         if (parm->msg_lev >= GLP_MSG_ALL)
          {  xprintf("Objective value = %.10g\n",
                lpp->orig_dir == LPX_MIN ? + lpp->c0 : - lpp->c0);
             xprintf("OPTIMAL SOLUTION FOUND BY LP PRESOLVER\n");
@@ -564,7 +573,7 @@ static int simplex2(glp_prob *orig, const glp_smcp *parm)
       }
       /* build resultant LP problem object */
       prob = lpp_build_prob(lpp);
-      if (parm->msg_lev >= 3)
+      if (parm->msg_lev >= GLP_MSG_ALL)
       {  int m = glp_get_num_rows(prob);
          int n = glp_get_num_cols(prob);
          int nnz = glp_get_num_nz(prob);
@@ -578,14 +587,22 @@ static int simplex2(glp_prob *orig, const glp_smcp *parm)
       /* scale the resultant problem */
       lpx_scale_prob(prob);
       /* build advanced initial basis */
-      lpx_adv_basis(prob);
+      {  LIBENV *env = lib_link_env();
+         int term_out = env->term_out;
+         if (!term_out || parm->msg_lev < GLP_MSG_ALL)
+            env->term_out = GLP_OFF;
+         else
+            env->term_out = GLP_ON;
+         lpx_adv_basis(prob);
+         env->term_out = term_out;
+      }
       /* try to solve the resultant problem */
       prob->it_cnt = orig->it_cnt;
       ret = simplex1(prob, parm);
       orig->it_cnt = prob->it_cnt;
       /* check if the optimal solution has been found */
       if (glp_get_status(prob) != GLP_OPT)
-      {  if (parm->msg_lev >= 3)
+      {  if (parm->msg_lev >= GLP_MSG_ERR)
             xprintf("glp_simplex: cannot recover undefined or non-optim"
                "al solution\n");
          if (ret == 0)
@@ -672,14 +689,20 @@ int glp_simplex(glp_prob *lp, const glp_smcp *parm)
       for (i = 1; i <= lp->m; i++)
       {  GLPROW *row = lp->row[i];
          if (row->type == GLP_DB && row->lb >= row->ub)
-         {  ret = GLP_EBOUND;
+         {  if (parm->msg_lev >= GLP_MSG_ERR)
+               xprintf("glp_simplex: row %d: lb = %g, ub = %g; incorrec"
+                  "t bounds\n", i, row->lb, row->ub);
+            ret = GLP_EBOUND;
             goto done;
          }
       }
       for (j = 1; j <= lp->n; j++)
       {  GLPCOL *col = lp->col[j];
          if (col->type == GLP_DB && col->lb >= col->ub)
-         {  ret = GLP_EBOUND;
+         {  if (parm->msg_lev >= GLP_MSG_ERR)
+               xprintf("glp_simplex: column %d: lb = %g, ub = %g; incor"
+                  "rect bounds\n", j, col->lb, col->ub);
+            ret = GLP_EBOUND;
             goto done;
          }
       }
