@@ -18,7 +18,7 @@
 *  License for more details.
 *
 *  You should have received a copy of the GNU General Public License
-*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+*  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 #include "glpipp.h"
@@ -743,6 +743,14 @@ static int reduce_bounds(IPP *ipp, IPPROW *row)
          else
             ff_max = +DBL_MAX;
          /* compute implied lower and upper bounds of x[j] */
+#if 1
+         /* do not use aij if it has small magnitude to prevent wrong
+            implied bounds; for example, 1e-15 * x1 >= x2 + x3, where
+            x1 >= -10, x2, x3 >= 0, would lead to wrong conclusion that
+            x1 >= 0 */
+         if (fabs(aij->val) < 1e-6)
+            lb = -DBL_MAX, ub = +DBL_MAX; else
+#endif
          if (aij->val > 0.0)
          {  if (row->lb == -DBL_MAX || ff_max == +DBL_MAX)
                lb = -DBL_MAX;
@@ -784,7 +792,11 @@ static int reduce_bounds(IPP *ipp, IPPROW *row)
             if (ub + delta <= col->ub) flag = 1;
          }
          /* if the change is significant, perform replacing */
+#if 0
          if (flag)
+#else
+         if (flag && lb < +1e15 && ub > -1e15)
+#endif
          {  switch(ipp_tight_bnds(ipp, col, lb, ub))
             {  case 0:
                   /* bounds remain unchanged; can never be */
