@@ -18,7 +18,7 @@
 *  License for more details.
 *
 *  You should have received a copy of the GNU General Public License
-*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+*  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 #include "glpapi.h"
@@ -424,6 +424,16 @@ void lpx_get_col_info(glp_prob *lp, int j, int *tagx, double *vx,
       return;
 }
 
+int lpx_eval_tab_row(LPX *lp, int k, int ind[], double val[])
+{     /* compute row of the simplex tableau */
+      return glp_eval_tab_row(lp, k, ind, val);
+}
+
+int lpx_eval_tab_col(LPX *lp, int k, int ind[], double val[])
+{     /* compute column of the simplex tableau */
+      return glp_eval_tab_col(lp, k, ind, val);
+}
+
 int lpx_ipt_status(glp_prob *lp)
 {     /* retrieve status of interior-point solution */
       int status;
@@ -494,6 +504,59 @@ int lpx_get_num_bin(LPX *lp)
       return glp_get_num_bin(lp);
 }
 
+int lpx_integer(LPX *lp)
+{     /* easy-to-use driver to the branch-and-bound method */
+      glp_iocp parm;
+      int ret;
+      glp_init_iocp(&parm);
+      switch (lpx_get_int_parm(lp, LPX_K_MSGLEV))
+      {  case 0:  parm.msg_lev = GLP_MSG_OFF;   break;
+         case 1:  parm.msg_lev = GLP_MSG_ERR;   break;
+         case 2:  parm.msg_lev = GLP_MSG_ON;    break;
+         case 3:  parm.msg_lev = GLP_MSG_ALL;   break;
+         default: xassert(lp != lp);
+      }
+      switch (lpx_get_int_parm(lp, LPX_K_BRANCH))
+      {  case 0:  parm.br_tech = GLP_BR_FFV;    break;
+         case 1:  parm.br_tech = GLP_BR_LFV;    break;
+         case 2:  parm.br_tech = GLP_BR_DTH;    break;
+         case 3:  parm.br_tech = GLP_BR_MFV;    break;
+         default: xassert(lp != lp);
+      }
+      switch (lpx_get_int_parm(lp, LPX_K_BTRACK))
+      {  case 0:  parm.bt_tech = GLP_BT_DFS;    break;
+         case 1:  parm.bt_tech = GLP_BT_BFS;    break;
+         case 2:  parm.bt_tech = GLP_BT_BPH;    break;
+         case 3:  parm.bt_tech = GLP_BT_BLB;    break;
+         default: xassert(lp != lp);
+      }
+      parm.tol_int = lpx_get_real_parm(lp, LPX_K_TOLINT);
+      parm.tol_obj = lpx_get_real_parm(lp, LPX_K_TOLOBJ);
+      if (lpx_get_real_parm(lp, LPX_K_TMLIM) < 0.0)
+         parm.tm_lim = INT_MAX;
+      else
+         parm.tm_lim = 1000.0 * lpx_get_real_parm(lp, LPX_K_TMLIM);
+      if (lpx_get_int_parm(lp, LPX_K_USECUTS) & LPX_C_GOMORY)
+         parm.gmi_cuts = GLP_ON;
+      else
+         parm.gmi_cuts = GLP_OFF;
+      if (lpx_get_int_parm(lp, LPX_K_USECUTS) & LPX_C_MIR)
+         parm.mir_cuts = GLP_ON;
+      else
+         parm.mir_cuts = GLP_OFF;
+      parm.mip_gap = lpx_get_real_parm(lp, LPX_K_MIPGAP);
+      ret = glp_intopt(lp, &parm);
+      switch (ret)
+      {  case 0:           ret = LPX_E_OK;      break;
+         case GLP_EBOUND:
+         case GLP_EROOT:   ret = LPX_E_FAULT;   break;
+         case GLP_EFAIL:   ret = LPX_E_SING;    break;
+         case GLP_ETMLIM:  ret = LPX_E_TMLIM;   break;
+         default:          xassert(ret != ret);
+      }
+      return ret;
+}
+
 int lpx_mip_status(glp_prob *lp)
 {     /* retrieve status of MIP solution */
       int status;
