@@ -18,7 +18,7 @@
 *  License for more details.
 *
 *  You should have received a copy of the GNU General Public License
-*  along with this program. If not, see <http://www.gnu.org/licenses/>.
+*  along with GLPK. If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 #include "glpapi.h"
@@ -1179,8 +1179,8 @@ feas: /* phase I: find a primal feasible basic solution */
             goto done;
          case LPX_E_INSTAB:
             if (spx->msg_lev >= 2)
-               print(prefix "numerical instability (primal simplex, pha"
-                  "se I)");
+               print(prefix "warning: numerical instability (primal sim"
+                  "plex, phase I)");
             goto feas;
          case GLP_EFAIL:
             if (spx->msg_lev >= 1)
@@ -1214,8 +1214,8 @@ opt:  /* phase II: find an optimal basic solution (primal simplex) */
             goto done;
          case LPX_E_INSTAB:
             if (spx->msg_lev >= 2)
-               print(prefix "numerical instability (primal simplex, pha"
-                  "se II)");
+               print(prefix "warning: numerical instability (primal sim"
+                  "plex, phase II)");
             goto feas;
          case GLP_EFAIL:
             if (spx->msg_lev >= 1)
@@ -1259,7 +1259,8 @@ dual: /* phase II: find an optimal basic solution (dual simplex) */
             goto done;
          case LPX_E_INSTAB:
             if (spx->msg_lev >= 2)
-               print(prefix "numerical instability (dual simplex)");
+               print(prefix "warning: numerical instability (dual simpl"
+                  "ex)");
             goto feas;
          case GLP_EFAIL:
             if (spx->msg_lev >= 1)
